An implementation of the Artificial Bee Colony (ABC) Algorithm
Source:R/ABCoptim-package.R
ABCoptim-package.RdThis is an implementation of Karaboga (2005) ABC optimization algorithm. It
was developed upon the basic version programmed in C and distributed
at the algorithm's official website (see the references).
Details
Any evident (precision) error should be blaimed to the package author (not to the algorithm itself).
Please visit the project home for more information: https://github.com/gvegayon/ABCoptim.
References
D. Karaboga, An Idea based on Honey Bee Swarm for Numerical Optimization, tech. report TR06,Erciyes University, Engineering Faculty, Computer Engineering Department, 2005 http://mf.erciyes.edu.tr/abc/pub/tr06_2005.pdf
Artificial Bee Colony (ABC) Algorithm (website) http://mf.erciyes.edu.tr/abc/index.htm
Basic version of the algorithm implemented in C (ABC's official
website) http://mf.erciyes.edu.tr/abc/form.aspx
Author
Maintainer: George Vega Yon g.vegayon@gmail.com (ORCID)
Authors:
George Vega Yon g.vegayon@gmail.com (ORCID)
Other contributors:
Enyelbert Muñoz enyeldoc2011@gmail.com [contributor]
Examples
if (FALSE) { # \dontrun{
demo(ABCoptim) # Some functions...
} # }